@@ -3,7 +3,8 @@
 # Load sample data included with GMT (downloaded from the GMT cache server).
 
 from pygmt.datasets.earth_relief import load_earth_relief
-from pygmt.datasets.tutorial import (
+from pygmt.datasets.samples import (
+    load_fractures_compilation,
     load_japan_quakes,
     load_ocean_ridge_points,
     load_sample_bathymetry,
