@@ -1,8 +1,13 @@
 """
 Functions, classes, decorators, and context managers to help wrap GMT modules.
 """
-from pygmt.helpers.decorators import fmt_docstring, kwargs_to_strings, use_alias
-from pygmt.helpers.tempfile import GMTTempFile, unique_name
+from pygmt.helpers.decorators import (
+    deprecate_parameter,
+    fmt_docstring,
+    kwargs_to_strings,
+    use_alias,
+)
+from pygmt.helpers.tempfile import GMTTempFile, tempfile_from_geojson, unique_name
 from pygmt.helpers.utils import (
     args_in_kwargs,
     build_arg_string,
