@@ -28,6 +28,7 @@ from pygmt.helpers import (
     X="xshift",
     Y="yshift",
     c="panel",
+    f="coltypes",
     p="perspective",
     t="transparency",
 )
@@ -69,6 +70,7 @@ def basemap(self, **kwargs):
     {V}
     {XY}
     {c}
+    {f}
     {p}
     {t}
     """
